pub async fn create_database(
backend: &StorageBackend,
) -> Result<Arc<dyn VirtualDatabase + Send + Sync>>Expand description
Create a virtual database instance based on the storage backend configuration
pub async fn create_database(
backend: &StorageBackend,
) -> Result<Arc<dyn VirtualDatabase + Send + Sync>>Create a virtual database instance based on the storage backend configuration