create_table_for_entity

Function create_table_for_entity 

pub async fn create_table_for_entity(
    database: &dyn VirtualDatabase,
    entity: &Entity,
) -> Result<()>
Create a database table for an entity

This is a convenience function that creates a table, indexes, and foreign keys for a single entity.

Arguments

  • database - The virtual database instance
  • entity - The entity to create a table for