MutationRuleManager

Struct MutationRuleManager 

pub struct MutationRuleManager { /* private fields */ }
Manager for mutation rules

Implementations

Source

impl MutationRuleManager

pub fn new() -> Self

Create a new mutation rule manager

pub async fn add_rule(&self, rule: MutationRule) -> Result<()>

Add a mutation rule

pub async fn remove_rule(&self, rule_id: &str) -> bool

Remove a mutation rule

pub async fn get_rule(&self, rule_id: &str) -> Option<MutationRule>

Get a mutation rule by ID

pub async fn list_rules(&self) -> Vec<MutationRule>

List all mutation rules

pub async fn list_rules_for_entity( &self, entity_name: &str, ) -> Vec<MutationRule>

List rules for a specific entity

pub async fn set_rule_enabled(&self, rule_id: &str, enabled: bool) -> Result<()>

Enable or disable a mutation rule

pub async fn check_and_execute( &self, database: &dyn VirtualDatabase, registry: &EntityRegistry, ) -> Result<usize>

Check for rules that should execute now and execute them

This should be called periodically or when time advances to check if any rules are due for execution.