pub async fn create_table_for_entity(
database: &dyn VirtualDatabase,
entity: &Entity,
) -> Result<()>Expand description
Create a database table for an entity
This is a convenience function that creates a table, indexes, and foreign keys for a single entity.
Arguments
database- The virtual database instanceentity- The entity to create a table for