pub struct MutationRuleManager { /* private fields */ }Expand description
Manager for mutation rules
Implementations
Sourceimpl MutationRuleManager
impl MutationRuleManager
Sourcepub async fn add_rule(&self, rule: MutationRule) -> Result<()>
pub async fn add_rule(&self, rule: MutationRule) -> Result<()>
Add a mutation rule
Sourcepub async fn remove_rule(&self, rule_id: &str) -> bool
pub async fn remove_rule(&self, rule_id: &str) -> bool
Remove a mutation rule
Sourcepub async fn get_rule(&self, rule_id: &str) -> Option<MutationRule>
pub async fn get_rule(&self, rule_id: &str) -> Option<MutationRule>
Get a mutation rule by ID
Sourcepub async fn list_rules(&self) -> Vec<MutationRule>
pub async fn list_rules(&self) -> Vec<MutationRule>
List all mutation rules
Sourcepub async fn list_rules_for_entity(
&self,
entity_name: &str,
) -> Vec<MutationRule>
pub async fn list_rules_for_entity( &self, entity_name: &str, ) -> Vec<MutationRule>
List rules for a specific entity
Sourcepub async fn set_rule_enabled(&self, rule_id: &str, enabled: bool) -> Result<()>
pub async fn set_rule_enabled(&self, rule_id: &str, enabled: bool) -> Result<()>
Enable or disable a mutation rule
Sourcepub async fn check_and_execute(
&self,
database: &dyn VirtualDatabase,
registry: &EntityRegistry,
) -> Result<usize>
pub async fn check_and_execute( &self, database: &dyn VirtualDatabase, registry: &EntityRegistry, ) -> Result<usize>
Check for rules that should execute now and execute them
This should be called periodically or when time advances to check if any rules are due for execution.